@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.17.0";
+our $VERSION = "v0.18.0";
 
 1;
 __END__
@@ -273,10 +273,10 @@ L<https://rxjs.dev/api/index/class/Subject>
 
 L<https://rxjs.dev/api/index/function/throwError>
 
-    # 0, 1, 2, 3, foo, 4, 5, 6, ...
-    rx_merge(
-        rx_of('foo')->pipe( op_delay(4.5) ),
-        rx_interval(1),
+    # 0, 1, 2, 3, error: foo
+    rx_concat(
+        rx_interval(1)->pipe( op_take(4) ),
+        rx_throw_error('foo'),
     )->subscribe($subscriber);
 
 =item rx_timer
@@ -308,6 +308,8 @@ too).
 
 L<https://rxjs.dev/api/operators/delay>
 
+Works like rxjs's "delay", except the parameter is in seconds instead of ms.
+
     # (pause 10 seconds) 0, 1, 2, 3
     rx_interval(1)->pipe( op_delay(10) )->subscribe($subscriber);
 
@@ -363,6 +365,39 @@ L<https://rxjs.dev/api/operators/scan>
 
 L<https://rxjs.dev/api/operators/share>
 
+    # t0, 0, 0, t1, 1, 1, t2, 2, 2, ...
+    my $o = rx_interval(1)->pipe(
+        op_tap(sub {say 't' . $_[0]}),
+        op_share(),
+    );
+
+    $o->subscribe($subscriber1);
+    $o->subscribe($subscriber2);
+
+=item op_start_with
+
+L<https://rxjs.dev/api/operators/startWith>
+
+    # 100, 200, 0, 1, 2, 3, complete
+    rx_of(0, 1, 2, 3)->pipe(
+        op_start_with(100, 200),
+    )->subscribe($subscriber);
+
+=item switch_map
+
+L<https://rxjs.dev/api/operators/switchMap>
+
+    # 1, 2, 3, 11, 12, 13, 21, 22, 23, 24, 25, 26, 27, ...
+    my $o = rx_interval(2.5)->pipe( op_take(3) );
+
+    $o->pipe(
+        op_switch_map(sub ($x) {
+            return rx_interval(0.7)->pipe(
+                op_map(sub ($y) { $x * 10 + $y + 1 }),
+            );
+        }),
+    )->subscribe($subscriber);
+
 =item op_take
 
 L<https://rxjs.dev/api/operators/take>
